@@ -1,5 +1,6 @@
 from __future__ import print_function
 from __future__ import division
+from .helptk import get_docstring
 import numpy as np
 from scipy.sparse import csc_matrix,bmat,csr_matrix
 import scipy.linalg as lg
@@ -21,6 +22,7 @@ from . import rotate_spin
 from . import topology
 from . import ldos
 from . import increase_hilbert
+from .sctk import dvector
 from .algebratk import hamiltonianalgebra
 from .bandstructure import get_bands_nd
 
@@ -198,6 +200,7 @@ class Hamiltonian():
     def add_swave(self,*args,**kwargs):
         """ Adds swave superconducting pairing"""
         superconductivity.add_swave_to_hamiltonian(self,*args,**kwargs)
+    def setup_nambu_spinor(self): self.add_swave(0.0)
     def get_anomalous_hamiltonian(self):
         """Return a Hamiltonian only with the anomalous part"""
         return superconductivity.get_anomalous_hamiltonian(self)
@@ -250,6 +253,7 @@ class Hamiltonian():
         self.turn_spinful()
         from .magnetism import add_magnetism
         add_magnetism(self,m)
+    def add_exchange(self,m): self.add_magnetism(m)
     def turn_spinful(self,enforce_tr=False):
       """Turn the hamiltonian spinful""" 
       if self.has_spin: return # already spinful
@@ -441,7 +445,7 @@ class Hamiltonian():
     def generate_spin_spiral(self,**kwargs):
         """ Generate a spin spiral antsaz in the Hamiltonian """
         return rotate_spin.generate_spin_spiral(self,**kwargs)
-    def get_magnetization(self,nkp=10):
+    def get_magnetization(self,**kwargs):
         """ Return the magnetization """
         mx = self.extract(name="mx")
         my = self.extract(name="my")
@@ -501,6 +505,9 @@ class Hamiltonian():
     def extract(self,name): 
         """Extract something from the Hamiltonian"""
         return extract.extract_from_hamiltonian(self,name)
+    @get_docstring(dvector.dvector_non_unitarity_map)
+    def write_non_unitarity(self,**kwargs):
+        dvector.dvector_non_unitarity_map(self,**kwargs)
     def write_magnetization(self,nrep=5):
         """Extract the magnetization and write it in a file"""
         mx = self.extract("mx")
@@ -536,12 +543,15 @@ class Hamiltonian():
         if self.dimensionality==0:
             return ipr.ipr(self.intra,**kwargs) 
         else: raise # not implemented
+    @get_docstring(dvector.dvector_non_unitarity)
+    def get_dvector_non_unitarity(self,**kwargs):
+        return dvector.dvector_non_unitarity(self,**kwargs)
     def get_density_matrix(self,**kwargs):
         """Return the density matrix"""
         from . import densitymatrix
         return densitymatrix.full_dm(self,**kwargs)
+    @get_docstring(superconductivity.average_hamiltonian_dvector)
     def get_average_dvector(self,**kwargs):
-        """Return a square average of the d-vector in the BZ"""
         return superconductivity.average_hamiltonian_dvector(self,**kwargs)
 
 
